package metrics_test

import (
	. "github.com/onsi/ginkgo"
	. "github.com/onsi/gomega"
	. "github.com/pivotal-cf-experimental/mysql-metrics/logger/loggerfakes"
	. "github.com/pivotal-cf-experimental/mysql-metrics/metrics"
	. "github.com/pivotal-cf-experimental/mysql-metrics/metrics/metricsfakes"
)

var _ = Describe("MetricWriter", func() {
	var (
		metric       Metric
		key          string
		value        float64
		unit         string
		metricWriter *MetricWriter
	)

	It("sends a metric ", func() {
		fakeSender := new(FakeSender)
		fakeLogger := new(FakeMetricsLogger)
		metricWriter = NewMetricWriter(fakeSender, fakeLogger)
		key = "metrics-key"
		value = 123.5
		unit = "unit"
		metric = Metric{Key: key, Value: value, Unit: unit, RawValue: "123.5000", HasError: false}
		metricWriter.Write(&metric)

		Expect(fakeSender.SendValueCallCount()).To(Equal(1))
		keyArg, valueArg, unitArg := fakeSender.SendValueArgsForCall(0)
		Expect(keyArg).To(Equal(key))
		Expect(valueArg).To(Equal(value))
		Expect(unitArg).To(Equal(unit))

		Expect(fakeLogger.DebugCallCount()).To(Equal(1))
		debugMessage, data := fakeLogger.DebugArgsForCall(0)
		Expect(debugMessage).To(ContainSubstring("Emitted metric"))
		metricFromDebug := data["metric"].(*Metric)
		Expect(*metricFromDebug).To(Equal(metric))
	})
})
